@@ -1,10 +1,7 @@
 from dataclasses import dataclass
-from pathlib import Path
 from subprocess import DEVNULL, Popen
 from typing import List
 
-from ycontract import contract
-
 
 @dataclass
 class Player:
@@ -13,8 +10,7 @@ class Player:
     started: bool = False
     _proc: Popen = Popen('echo', stdout=DEVNULL, stderr=DEVNULL)
 
-    @property  # type: ignore
-    @contract(lambda self: Path(self.sound_filename).exists())
+    @property
     def play_commands(self) -> List[str]:
         commands = ['mplayer', self.sound_filename]
         return commands
